Crate vortex_json

Crate vortex_json 

Extension type and related functionality for a JSON extension type for Vortex.

Structs

Json
JSON logical type backed by UTF-8 string storage.
JsonToVariant
Parses JSON strings into Variant values, optionally shredding fields.
JsonToVariantOptions
Options for JsonToVariant.
ShreddingSpec
A list of (path, dtype) directives describing which Variant paths to shred and as what type.

Functions

initialize
Register JSON extension support with a session.
json_to_variant
Creates a JsonToVariant expression that parses child’s JSON strings into Variant values, shredding the paths selected by shredding.